LocationSource class sealed
Selects which source feeds location updates into the map's user-location component (the "puck").
Pass an instance to MapLibreMap.locationSource. It only has an effect when
myLocationEnabled is set to true.
See also:
- PlatformLocationSource, the default native location engine.
- ManualLocationSource, app-provided locations pushed via
MapLibreMapController.updateManualLocation.
- Implementers
- Annotations
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited