SkyProperties class

Properties of the style's sky root object.

Constructors

SkyProperties({dynamic skyColor, dynamic horizonColor, dynamic fogColor, dynamic fogGroundBlend, dynamic horizonFogBlend, dynamic skyHorizonBlend, dynamic atmosphereBlend})
const

Properties

atmosphereBlend → dynamic
atmosphere-blend: how to blend the atmosphere, where 1 is a visible atmosphere and 0 a hidden one. Best interpolated by zoom when using the globe projection.
final
fogColor → dynamic
fog-color: the base color for the fog. Requires 3D terrain.
final
fogGroundBlend → dynamic
fog-ground-blend: how to blend the fog over the 3D terrain, where 0 is the map center and 1 is the horizon.
final
hashCode int
The hash code for this object.
no setterinherited
horizonColor → dynamic
horizon-color: the base color at the horizon.
final
horizonFogBlend → dynamic
horizon-fog-blend: how to blend the fog color and the horizon color, where 0 uses the horizon color only and 1 the fog color only.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skyColor → dynamic
sky-color: the base color for the sky.
final
skyHorizonBlend → dynamic
sky-horizon-blend: how to blend the sky color and the horizon color, where 1 blends the color at the middle of the sky and 0 does not blend at all and uses the sky color only.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited